==> mono-2.10.2.tar.bz2: mono-2.10.2/mcs/class/System/System/GenericUriParserOptions.cs <==
//
// System.GenericUriParserOptions enumeration
//
// Author:
//	Sebastien Pouliot  <sebastien@ximian.com>
//
// Copyright (C) 2005, 2008 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

namespace System {

	[Flags]
#if NET_2_0
	public
#endif
	enum GenericUriParserOptions {

		Default = 0,
		GenericAuthority = 1,
		AllowEmptyAuthority = 2,
		NoUserInfo = 4,
		NoPort = 8,
		NoQuery = 16,
		NoFragment = 32,
		DontConvertPathBackslashes = 64,
		DontCompressPath = 128,
		DontUnescapePathDotsAndSlashes = 256,
		Idn = 512,
		IriParsing = 1024
	}
}

==> mono-4.4.2.11.tar.bz2: mono-4.4.2/mcs/class/System/System/GenericUriParserOptions.cs <==
//
// System.GenericUriParserOptions enumeration
//
// Author:
//	Sebastien Pouliot  <sebastien@ximian.com>
//
// Copyright (C) 2005, 2008 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

namespace System {

	[Flags]
	public enum GenericUriParserOptions {

		Default = 0,
		GenericAuthority = 1,
		AllowEmptyAuthority = 2,
		NoUserInfo = 4,
		NoPort = 8,
		NoQuery = 16,
		NoFragment = 32,
		DontConvertPathBackslashes = 64,
		DontCompressPath = 128,
		DontUnescapePathDotsAndSlashes = 256,
		Idn = 512,
		IriParsing = 1024
	}
}
